==> pyphant.imageprocessing-0.8a2.tar.gz: pyphant.imageprocessing-0.8a2/ImageProcessing/ConetworkSeparator.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2006-2007, Rectorate of the University of Freiburg
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# * Neither the name of the Freiburg Materials Research Center,
#   University of Freiburg nor the names of its contributors may be used to
#   endorse or promote products derived from this software without specific
#   prior written permission.
#
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

u"""
"""

__id__ = "$Id$"
__author__ = "$Author$"
__version__ = "$Revision$"
# $Source$

from pyphant.core import Worker, Connectors,\
                         Param, DataContainer

import ImageProcessing

import scipy, copy

class ConetworkThresholding(Worker.Worker):
    API = 2
    VERSION = 1
    REVISION = "$Revision$"[11:-1]
    name = "Thresholdfilter"
    _sockets = [("image", Connectors.TYPE_IMAGE)]
    _params = [("feature [wt]", "FeatureWT", 50, None),
               ("feature mass density [mg/ml]","FeatureRho",970,None),
               ("background mass density [mg/ml]","BackgroundRho",1290,None)]

    def getCovering(self):
        wt = self.paramFeatureWT.value
        PDMS=self.paramFeatureRho.value
        PHEA=self.paramBackgroundRho.value

        covering = wt * PHEA / (wt * PHEA + (1.0-0.01*wt)*PDMS)
        return covering

    @Worker.plug(Connectors.TYPE_IMAGE)
    def threshold(self, image, subscriber=0):
        th=self.paramThreshold.value
        resultArray = scipy.where( image.data < th,
                                   ImageProcessing.FEATURE_COLOR,
                                   ImageProcessing.BACKGROUND_COLOR )
        result = DataContainer.FieldContainer(resultArray,
                                              dimensions=copy.deepcopy(image.dimensions),
                                              longname=u"Binary Image", shortname=u"B")
        result.seal()
        return result

==> pyphant.imageprocessing-1.0b3.tar.gz: pyphant.imageprocessing-1.0b3/ImageProcessing/ConetworkSeparator.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2006-2007, Rectorate of the University of Freiburg
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# * Neither the name of the Freiburg Materials Research Center,
#   University of Freiburg nor the names of its contributors may be used to
#   endorse or promote products derived from this software without specific
#   prior written permission.
#
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

u"""
"""

from pyphant.core import Worker, Connectors, DataContainer
import ImageProcessing
import scipy
import copy
import pkg_resources


class ConetworkThresholding(Worker.Worker):
    API = 2
    VERSION = 1
    REVISION = pkg_resources.get_distribution(
        "pyphant.imageprocessing"
        ).version
    name = "Thresholdfilter"
    _sockets = [("image", Connectors.TYPE_IMAGE)]
    _params = [
        ("feature [wt]", "FeatureWT", 50, None),
        ("feature mass density [mg/ml]", "FeatureRho", 970, None),
        ("background mass density [mg/ml]", "BackgroundRho", 1290, None)
        ]

    def getCovering(self):
        wt = self.paramFeatureWT.value
        PDMS = self.paramFeatureRho.value
        PHEA = self.paramBackgroundRho.value

        covering = wt * PHEA / (wt * PHEA + (1.0 - 0.01 * wt) * PDMS)
        return covering

    @Worker.plug(Connectors.TYPE_IMAGE)
    def threshold(self, image, subscriber=0):
        th = self.paramThreshold.value
        resultArray = scipy.where(
            image.data < th,
            ImageProcessing.FEATURE_COLOR,
            ImageProcessing.BACKGROUND_COLOR
            )
        result = DataContainer.FieldContainer(
            resultArray,
            dimensions=copy.deepcopy(image.dimensions),
            longname=u"Binary Image", shortname=u"B"
            )
        result.seal()
        return result
